==> qtjambi-dbus-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiDBus/QDBusContext_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtDBus/qdbuscontext.h>
#include <QtCore/QVariant>
#include <QtDBus/qdbusconnection.h>
#include <QtDBus/qdbusmessage.h>
#include <QtDBus/qdbuserror.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDBusContext(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDBusContext")
    QDBusContext *_ptr = reinterpret_cast<QDBusContext *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QDBusContext_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QDBusContext *__qt_this = new(__qtjambi_ptr) QDBusContext();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QDBusContext
void __qt_destruct_QDBusContext(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDBusContext")
    reinterpret_cast<QDBusContext*>(ptr)->~QDBusContext();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDBusContext::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_initialize_1native__Lio_qt_dbus_QDBusContext_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusContext::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusContext_0, sizeof(QDBusContext), typeid(QDBusContext), false, &deleter_QDBusContext, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusContext::calledFromDBus()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_calledFromDBus_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusContext::calledFromDBus()const", __qt_this)
        __java_return_value = __qt_this->QDBusContext::calledFromDBus();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusContext::connection()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_connection_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusContext::connection()const", __qt_this)
        QDBusConnection __qt_return_value = __qt_this->QDBusContext::connection();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusContext::isDelayedReply()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_isDelayedReply_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusContext::isDelayedReply()const", __qt_this)
        __java_return_value = __qt_this->QDBusContext::isDelayedReply();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusContext::message()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_message_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusContext::message()const", __qt_this)
        const QDBusMessage& __qt_return_value = __qt_this->QDBusContext::message();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusContext::sendErrorReply(QDBusError::ErrorType,QString)const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_sendErrorReply_1native_1QDBusError_1ErrorType_1cref_1QString_1constfct__JILjava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jint type0,
 jstring msg1)
{
    QTJAMBI_TRY {
        const QDBusContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusContext::sendErrorReply(QDBusError::ErrorType,QString)const", __qt_this)
        QDBusError::ErrorType __qt_type0 = qtjambi_cast<QDBusError::ErrorType>(__jni_env, type0);
        QString  __qt_msg1 = qtjambi_cast<QString >(__jni_env, msg1);
        __qt_this->QDBusContext::sendErrorReply(QDBusError::ErrorType(__qt_type0), __qt_msg1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusContext::sendErrorReply(QString,QString)const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_sendErrorReply_1native_1cref_1QString_1cref_1QString_1constfct__JLjava_lang_String_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jstring name0,
 jstring msg1)
{
    QTJAMBI_TRY {
        const QDBusContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusContext::sendErrorReply(QString,QString)const", __qt_this)
        QString  __qt_name0 = qtjambi_cast<QString >(__jni_env, name0);
        QString  __qt_msg1 = qtjambi_cast<QString >(__jni_env, msg1);
        __qt_this->QDBusContext::sendErrorReply(__qt_name0, __qt_msg1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusContext::setDelayedReply(bool)const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_setDelayedReply_1native_1bool_1constfct__JZ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jboolean enable0)
{
    QTJAMBI_TRY {
        const QDBusContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusContext::setDelayedReply(bool)const", __qt_this)
        __qt_this->QDBusContext::setDelayedReply(static_cast<bool>(enable0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_clone_1native)
(JNIEnv *__jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDBusContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDBusContext(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceValueTypeInfo<QDBusContext>("QDBusContext", "io/qt/dbus/QDBusContext");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDBusContext, {
        ConstructorInfo(&__qt_construct_QDBusContext_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDBusContext);
    registerMetaType<QDBusContext>("QDBusContext");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-dbus-debuginfo-windows-x64-6.7.2.jar: sources/QtJambiDBus/QDBusContext_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtDBus/qdbuscontext.h>
#include <QtCore/QVariant>
#include <QtDBus/qdbusconnection.h>
#include <QtDBus/qdbuserror.h>
#include <QtDBus/qdbusmessage.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDBusContext(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDBusContext")
    QDBusContext *_ptr = reinterpret_cast<QDBusContext *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDBusContext()
void __qt_construct_QDBusContext(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusContext()")
    Q_UNUSED(__java_arguments)
    QDBusContext *__qt_this = new(__qtjambi_ptr) QDBusContext();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QDBusContext::QDBusContext()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_initialize_1native__Lio_qt_dbus_QDBusContext_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusContext::QDBusContext()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusContext, sizeof(QDBusContext), typeid(QDBusContext), 0, false, &deleter_QDBusContext, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDBusContext(QDBusContext)
void __qt_construct_QDBusContext_cref_QDBusContext(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusContext(QDBusContext)")
    jobject other0 = __java_arguments[0].l;
    const QDBusContext& __qt_other0 = qtjambi_cast<const QDBusContext&>(__jni_env, other0);
    QDBusContext *__qt_this = new(__qtjambi_ptr) QDBusContext(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDBusContext::QDBusContext(QDBusContext)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_initialize_1native__Lio_qt_dbus_QDBusContext_2Lio_qt_dbus_QDBusContext_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusContext::QDBusContext(QDBusContext)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusContext_cref_QDBusContext, sizeof(QDBusContext), typeid(QDBusContext), 0, false, &deleter_QDBusContext, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDBusContext
void __qt_destruct_QDBusContext(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDBusContext")
    reinterpret_cast<QDBusContext*>(ptr)->~QDBusContext();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDBusContext::calledFromDBus()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_calledFromDBus_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusContext::calledFromDBus()const", __this_nativeId)
        __java_return_value = __qt_this->QDBusContext::calledFromDBus();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusContext::connection()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_connection_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusContext::connection()const", __this_nativeId)
        QDBusConnection __qt_return_value = __qt_this->QDBusContext::connection();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusContext::isDelayedReply()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_isDelayedReply_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusContext::isDelayedReply()const", __this_nativeId)
        __java_return_value = __qt_this->QDBusContext::isDelayedReply();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusContext::message()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_message_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusContext::message()const", __this_nativeId)
        const QDBusMessage& __qt_return_value = __qt_this->QDBusContext::message();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusContext::sendErrorReply(QDBusError::ErrorType,QString)const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_sendErrorReply_1native_1QDBusError_1ErrorType_1cref_1QString_1constfct__JILjava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jint type0,
 jstring msg1)
{
    QTJAMBI_TRY {
        const QDBusContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusContext::sendErrorReply(QDBusError::ErrorType,QString)const", __this_nativeId)
        QDBusError::ErrorType __qt_type0 = qtjambi_cast<QDBusError::ErrorType>(__jni_env, type0);
        QString __qt_msg1 = qtjambi_cast<QString>(__jni_env, msg1);
        __qt_this->QDBusContext::sendErrorReply(QDBusError::ErrorType(__qt_type0), __qt_msg1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusContext::sendErrorReply(QString,QString)const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_sendErrorReply_1native_1cref_1QString_1cref_1QString_1constfct__JLjava_lang_String_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jstring name0,
 jstring msg1)
{
    QTJAMBI_TRY {
        const QDBusContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusContext::sendErrorReply(QString,QString)const", __this_nativeId)
        QString __qt_name0 = qtjambi_cast<QString>(__jni_env, name0);
        QString __qt_msg1 = qtjambi_cast<QString>(__jni_env, msg1);
        __qt_this->QDBusContext::sendErrorReply(__qt_name0, __qt_msg1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusContext::setDelayedReply(bool)const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_setDelayedReply_1native_1bool_1constfct__JZ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jboolean enable0)
{
    QTJAMBI_TRY {
        const QDBusContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusContext::setDelayedReply(bool)const", __this_nativeId)
        __qt_this->QDBusContext::setDelayedReply(static_cast<bool>(enable0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusContext_00024Impl_clone_1native)
(JNIEnv *__jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDBusContext *__qt_this = QtJambiAPI::interfaceFromNativeId<QDBusContext>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDBusContext(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceValueTypeInfo<QDBusContext>("QDBusContext", "io/qt/dbus/QDBusContext");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDBusContext, {
        ConstructorInfo(&__qt_construct_QDBusContext, nullptr)
       ,ConstructorInfo(&__qt_construct_QDBusContext_cref_QDBusContext, "Lio/qt/dbus/QDBusContext;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDBusContext);
    registerMetaType<QDBusContext>("QDBusContext");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
